"use client";
import DataTable from "@/components/tables/DataTable";
import { DeleteIcon, EditIcon } from "@chakra-ui/icons";
import { Button, Flex, Icon, Switch, Text, useColorModeValue, useDisclosure, useToast } from "@chakra-ui/react";
import { useRouter } from "next/navigation";
import { useState } from "react";
import { ProjectInterface } from "../types/type";
import { columnsDataBlocks } from "../variables/columnsBlock";
import ProjectModalForm from "./form";
import {
  createProjectModuleEntry,
  deleteProjectModuleEntry,
  editProjectModuleEntry,
} from "@/app/lib/project/action";
import { ProjectFormInterface } from "@/types/project";

interface ProjectTableProps {
  data: { data: ProjectInterface[] };
}

const ProjectTable: React.FC<ProjectTableProps> = ({ data }) => {
  const { isOpen, onOpen, onClose } = useDisclosure();
  const [selectedProject, setSelectedProject] = useState<ProjectFormInterface | null>(null);
  const toast = useToast();
  const textColor = useColorModeValue("secondaryGray.900", "white");
  const brandColor = useColorModeValue("brand.500", "white");
  const router = useRouter();
  const [tableData, setTableData] = useState(data?.data);

  const deleteProjectHandler = async (id: number) => {
      const res = await deleteProjectModuleEntry(id);
      if (res?.status == 200) {
        toast({
          title: "Success",
          description: res.message,
          status: "success",
          position: "top-right",
          duration: 2000,
          isClosable: true,
        });
        router.refresh();
      } else {
        toast({
          title: "Error",
          description: res.message,
          status: "error",
          position: "top-right",
          duration: 9000,
          isClosable: true,
        });
      }
  };

  const handleAddClick = () => {
    setSelectedProject(null); // Set to null for "Create" mode
    onOpen();
  };

  const handleEditClick = (project: ProjectInterface) => {
    const singleUser = data?.data?.find((item: any) => (item.id == project));    
    setSelectedProject ((prev) => {
      return { ...singleUser };
    });
    onOpen();
    };

  const handleSubmit = async (values: any) => {
      if (selectedProject) {
        const payload = { projectId: selectedProject.id, data: values };
        const res = await editProjectModuleEntry(payload);
        if (res?.status == 200) {
          toast({
            title: "Success",
            description: res.message,
            status: "success",
            position: "top-right",
            duration: 2000,
            isClosable: true,
          });
          onClose();
          router.refresh();
        } else {
          toast({
            title: "Error",
            description: res.message,
            status: "error",
            position: "top-right",
            duration: 9000,
            isClosable: true,
          });
        }
      } else {
        const res: any = await createProjectModuleEntry(values);
        if (res?.status == 200) {
          toast({
            title: "Success",
            description: res.message,
            status: "success",
            position: "top-right",
            duration: 2000,
            isClosable: true,
          });
          onClose();
          router.refresh();
        } else {
          toast({
            title: "Error",
            description: res.message,
            status: "error",
            position: "top-right",
            duration: 9000,
            isClosable: true,
          });
        }
      }
    }; 

  const action = (project: any) => (
    <Flex gap={2}>
      <Button
        variant="blank"
        onClick={() => handleEditClick(project)}
        w="37px"
        h="37px"
        borderRadius="10px"
      >
        <Icon as={EditIcon} color={brandColor} w="20px" h="20px" />
      </Button>
      <Button
        variant="blank"
        onClick={() => deleteProjectHandler(project)}
        w="37px"
        h="37px"
        borderRadius="10px"
      >
        <Icon as={DeleteIcon} color={brandColor} w="20px" h="20px" />
      </Button>
    </Flex>
  );

  

  return (
    <>
      <DataTable
        addButton={
          <Button
            variant="solid"
            color={textColor}
            onClick={handleAddClick}
          >
            + Add
          </Button>
        }
        columnsData={columnsDataBlocks}
        tableData={data?.data as unknown as ProjectInterface[] }
        paginate={data}
        isSelectable={false}
        showPageSize={false}
        actionSlot={(project: any) => action(project)}
      />

      <ProjectModalForm
        isOpen={isOpen}
        onClose={onClose}
        currentUser={selectedProject} // Dynamically pass selected project or null
        handleSubmit={handleSubmit}
      />
    </>
  );
};

export default ProjectTable;